@@ -761,7 +761,14 @@ prMergeClr<- function(clrs){
 prPrepareCss <- function(x, css, rnames, header, name = deparse(substitute(css))){
   css.header <- rep("", times = ncol(x))
   css.rnames <- rep("", times = nrow(x) + !missing(header))
+  if (is.data.frame(css))
+    css <- as.matrix(css)
+
   if (is.matrix(css)){
+    if (any(grepl("^[^:]*[a-zA-Z]+[:]*:", css))){
+      rownames(css) <- NULL
+      colnames(css) <- NULL
+    }
     if (ncol(css) == ncol(x) + 1 &&
           !prSkipRownames(rnames)){
       if (!missing(header)){
